/* small fts test program */

#include <stdio.h>
#include <fts.h>
#include <string.h>

#define DEBUG printf
#define DEBUG2 printf

static int comparefts(const FTSENT **a, const FTSENT **b) {
    if ( (*a)->fts_info == FTS_ERR || (*b)->fts_info == FTS_ERR) {
		return 0;
    }
    if ( (*a)->fts_info == FTS_NS || (*b)->fts_info == FTS_NS) {
	if ( (*a)->fts_info != FTS_NS) {
	    return -1;
	} else if ( (*b)->fts_info != FTS_NS) {
	    return 1;
	} else {
	    return strcmp( (*a)->fts_name, (*b)->fts_name);
	}
    }
    return strcmp( (*a)->fts_name, (*b)->fts_name);
}

static char * ifp_compose_name(const char *str1, const char *str2)
{
	char *tmp;

	tmp=(char *) malloc(strlen(str1)+strlen(str2)+2);
	strcpy(tmp, str1);
	strcat(tmp, "/");
	strcat(tmp, str2);
	return tmp;
}

static int test_ifp_upload_dir(const char *id, const char *ld)
{
	FTS *ftsp;
	FTSENT *ftsentp;
	size_t basename_pos;
	int r;
	char *dirname, *iname, *id2, *ld2;
	char *argv[2];

	DEBUG("ifp_upload_dir(): begin -- id=%s ld=%s\n",id, ld);

	id2 = strdup(id);
	ld2 = strdup(ld);
	if (strcmp(id2,"/") == 0) strcpy(id2,""); 
	argv[0] = ld2;
	argv[1] = NULL;

	if ( (ftsp = fts_open(argv, FTS_LOGICAL, comparefts)) == NULL) {
	    perror("fts_open");
		/* FIXME: Shouldn't we bail out here? */
		free(id2);
		free(ld2);
	}
	
	basename_pos = strlen((const char *)ld2) - strlen((const char *)basename(ld2));
	DEBUG("ifp_upload_dir(): strlen(ld2)=%d strlen(basename(ld2)=%d diff %d\n",
	  strlen((const char *)ld2), strlen((const char *)basename(ld2)), basename_pos);

	while ( (ftsentp = fts_read(ftsp)) != NULL) {
		iname = ifp_compose_name(id2, ftsentp->fts_path + basename_pos);
		DEBUG("ifp_upload_dir(): while iname %s id2=%s fts_path %s, fts_path+basename %s\n", iname, 
			id2, ftsentp->fts_path, ftsentp->fts_path + basename_pos); 

		switch (ftsentp->fts_info) {
		case FTS_F:
			DEBUG2("F: ifp_upload_file() -- iname=%s ftsentp->fts_path=%s\n", iname, ftsentp->fts_path);
			//r = ifp_upload_file(dh, iname, ftsentp->fts_path, progress);
			break;
		case FTS_D:
			DEBUG2("D: ifp_make_dir() - iname=%s\n",iname);
			//r = ifp_make_dir(dh, iname);
			break;
		default:
			break;
		}
		free(iname);
	}

	if (fts_close(ftsp) == -1) {
		perror("fts_close");
		free(id2);
		free(ld2);
		return -1;
	}
	DEBUG("ifp_upload_dir(): end -- r=%d\n",r);
	free(id2);
	free(ld2);
	return r;
}

int main(int argc, char *argv[])
{
	printf("start\n");
	printf("ret %d", test_ifp_upload_dir(argv[1], argv[2]));

	return 0;
}
